'use client'
import { createOrUpdateContactsService } from "@/feature/messenger/services/chat/OptionsMessageService";
import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import { useState } from "react";
import toast from 'react-hot-toast';
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { Button, Input, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader } from "@nextui-org/react";
import { useTranslation } from "@/hooks/useTranslation";
import usePermissionChat from "@/feature/messenger/hooks/usePermissionChat";

const NewContactModal = () => {

  //store 
  const id_chatbot = useConfigChatStore(state => state.idChatbot);
  const openModalNewContact = useHandleConversationStore(state => state.openModalNewContact);
  const handleOpenModalNewContact = useHandleConversationStore(state => state.actions.handleOpenModalNewContact);
  const { trans } = useTranslation();
  const permission = usePermissionChat();

  const [loading, setLoading] = useState(false);
  const [formContacts, setFormContacts] = useState({
    name: "",
    city: "",
    email: "",
    phone: "",
    address: "",
    state: "",
    management1: "",
    management2: "",
  })

  const hadlerChangeForm = (e: any) => {
    setFormContacts({
      ...formContacts,
      [e.target.name]: e.target.value
    })
  }

  const handleSubmitContacts = async (e: any) => {
    e.preventDefault();
    setLoading(true);

    const res = await createOrUpdateContactsService(id_chatbot, formContacts.phone, formContacts)
    const response = res
    if (response.success == true) {
      toast.success(trans("modal_conversations_new_contact_alert_success_title"))
    } else {
      if (response.isExists == true) {
        toast.success(trans("modal_conversations_new_contact_alert_exists_title"))
      }else{
        toast.error(trans("modal_conversations_new_contact_alert_error_title"))
      }
    }
    setLoading(false);
    setFormContacts({
      name: '',
      city: '',
      email: '',
      address: '',
      state: '',
      management1: '',
      management2: '',
      phone: '',
    })

    setLoading(false);
  }

  const getVisibleFields = () => {
    const fields = [
      <Input
        key="name"
        isRequired
        label="Nombre"
        type="text"
        name="name"
        value={formContacts.name}
        onChange={hadlerChangeForm}
      />,
      <Input
        key="phone"
        isRequired
        label="Teléfono"
        type="text"
        name="phone"
        value={formContacts.phone}
        onChange={hadlerChangeForm}
      />,
      permission.crea_agenda_ciudad && (
        <Input
          key="city"
          label="Ciudad"
          type="text"
          name="city"
          value={formContacts.city}
          onChange={hadlerChangeForm}
        />
      ),
      permission.crea_agenda_email && (
        <Input
          isRequired
          label="Correo"
          type="text"
          name="email"
          value={formContacts.email}
          onChange={hadlerChangeForm}
        />
      ),
      permission.crea_agenda_direccion && (
        <Input
          label="Dirección"
          type="text"
          name="address"
          value={formContacts.address}
          onChange={hadlerChangeForm}
        />
      ),
      permission.crea_agenda_status && (
        <Input
          label="Estado"
          type="text"
          name="state"
          value={formContacts.state}
          onChange={hadlerChangeForm}
        />
      ),
      permission.crea_agenda_campo1 && (
        <Input
          label="Gestion 1"
          type="text"
          name="management1"
          value={formContacts.management1}
          onChange={hadlerChangeForm}
        />
      ),
      permission.crea_agenda_campo2 && (
        <Input
          label="Gestion 2"
          type="text"
          name="management2"
          value={formContacts.management2}
          onChange={hadlerChangeForm}
        />
      )
    ].filter(Boolean) as JSX.Element[];

    return fields;
  };

  const renderFieldPair = (fields: JSX.Element[], pairIndex: number) => {
    return fields.map((field, index) => (
        <div key={`${pairIndex}-${index}`} className="space-y-2">
            {field}
        </div>
    ));
  };

  const renderFieldPairs = () => {
    const visibleFields = getVisibleFields();
    const pairs = [];

    for (let i = 0; i < visibleFields.length; i += 2) {
        const pair = visibleFields.slice(i, i + 2);
        pairs.push(
            <div key={`pair-${i}`} className="grid grid-cols-2 gap-4">
                {renderFieldPair(pair, i)}
            </div>
        );
    }

    return <div className="space-y-4">{pairs}</div>;
  };

  return (
    <Modal isOpen={openModalNewContact} onOpenChange={handleOpenModalNewContact} size="3xl">
      <ModalContent>
        {(onClose) => (
          <>
            <ModalHeader>
              {trans("modal_conversations_new_contact_title")}
            </ModalHeader>
            <form onSubmit={(e) => handleSubmitContacts(e)} onSubmitCapture={(e) => e.preventDefault()}>
              <ModalBody>
                <div className="w-full">
                  {renderFieldPairs()}
                </div>
              </ModalBody>
              <ModalFooter>
                <Button color="danger" variant="light" isDisabled={loading} onClick={handleOpenModalNewContact}>
                  {trans("modal_conversations_new_contact_button_cancel_title")}
                </Button>
                <Button type="submit" color="primary" isLoading={loading}>
                  {loading ? trans("modal_conversations_new_contact_button_send_loading_title") : trans("modal_conversations_new_contact_button_send_title")}
                </Button>
              </ModalFooter>
            </form>
          </>
        )}
      </ModalContent>
    </Modal>
  )
}

export default NewContactModal